pygeodesy.triaxials.triaxial5.Conformal2Tuple

Package pygeodesy :: Package triaxials :: Module triaxial5 :: Class Conformal2Tuple |
[frames] | no frames]

# Class Conformal2Tuple

           object --+
                    |
                tuple --+
                        |
           object --+   |
                    |   |
         named._Named --+
                        |
        named._NamedTuple --+
                            |
    namedTuples._NamedTupleTo --+
                                |
                   _NamedTupleToX --+
                                    |
                                   Conformal2Tuple

Known Subclasses:
  - deprecated.classes.Jacobi2Tuple

2-Tuple `(x, y)` with a Jacobi Conformal `x` and `y` projection, both in Radians (or Degrees).

Instance Methods
to5Tuple(self, b_conformal, **z_scale_name) Return this Conformal2Tuple as a Conformal5Tuple. |
toDegrees(self, name='', **toDMS_kwds) Convert this Conformal2Tuple to Degrees or `toDMS`. |
toRadians(self, **name) Convert this Conformal2Tuple to Radians. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### to5Tuple (self, b_conformal, **z_scale_name) |
Return this Conformal2Tuple as a Conformal5Tuple. Arguments: `b_conformal` - Middle semi-axis (`meter`, conventionally) or the original Conformal of this 2-tuple. `z_scale_name` - Optional `z=0` meter, `scale=NAN` and `name=NN` (`str`). Returns: A Conformal5Tuple.

### toDegrees (self, name='', **toDMS_kwds) |
Convert this Conformal2Tuple to Degrees or `toDMS`. Arguments: `name` - Optional `name=NN` (`str`). Returns: Conformal2Tuple`(x, y)` with `x` and `y` both in Degrees or as toDMS strings provided some `toDMS_kwds` keyword arguments are specified.

### toRadians (self, **name) |
Convert this Conformal2Tuple to Radians. Arguments: `name` - Optional `name=NN` (`str`). Returns: Conformal2Tuple`(x, y)` with `x` and `y` both in Radians.